import { __assign } from './../external/tslib/tslib.es6.js';
import React, { useState } from 'react';
import classnames from 'classnames';
import { useScrollObserver } from '@highlight-ui/utils-hooks';
import { parseMetadata, suffixMetadata } from '@highlight-ui/utils-commons';
import { IconButton, Button } from '@highlight-ui/button';
import { Tooltip } from '@highlight-ui/tooltip';
import { Typography } from '@highlight-ui/typography';
import styles from './Dialog.module.scss.js';
import Modal from './Modal.js';
var DEFAULT_LABEL_ID = 'dialog-title';

var DialogButton = function (_a) {
  var _b, _c;

  var onClick = _a.onClick,
      buttonState = _a.buttonState,
      buttonLabel = _a.buttonLabel,
      buttonIcon = _a.buttonIcon,
      buttonAriaLabel = _a.buttonAriaLabel,
      buttonType = _a.buttonType,
      buttonForm = _a.buttonForm,
      buttonMetadata = _a.metadata,
      isPrimary = _a.isPrimary,
      variant = _a.variant,
      tooltip = _a.tooltip,
      onDialogButtonFocus = _a.onDialogButtonFocus;

  var getVariant = function () {
    if (!isPrimary) return 'default';
    return variant === 'destructive' ? 'critical' : 'primary';
  };

  var button = buttonIcon ? /*#__PURE__*/React.createElement(IconButton, __assign({
    className: classnames(styles.footerAction, (_b = {}, _b[styles.disabled] = buttonState === 'disabled', _b['dialog-danger'] = isPrimary && variant === 'destructive', _b['dialog-primary'] = isPrimary && variant !== 'destructive', _b)),
    type: buttonType,
    form: buttonForm,
    onClick: onClick,
    icon: buttonIcon,
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    ariaLabel: buttonAriaLabel,
    buttonState: buttonState,
    variant: getVariant()
  }, parseMetadata(buttonMetadata), {
    onFocus: onDialogButtonFocus
  })) : /*#__PURE__*/React.createElement(Button, __assign({
    className: classnames(styles.footerAction, (_c = {}, _c[styles.disabled] = buttonState === 'disabled', _c['dialog-danger'] = isPrimary && variant === 'destructive', _c['dialog-primary'] = isPrimary && variant !== 'destructive', _c)),
    type: buttonType,
    form: buttonForm,
    onClick: onClick,
    buttonState: buttonState,
    variant: getVariant()
  }, parseMetadata(buttonMetadata), {
    onFocus: onDialogButtonFocus
  }), buttonLabel);

  if (tooltip) {
    return /*#__PURE__*/React.createElement(Tooltip, __assign({}, tooltip), /*#__PURE__*/React.createElement("div", null, button));
  }

  return button;
};

var Dialog = function (_a) {
  var _b, _c;

  var metadata = _a.metadata,
      children = _a.children,
      className = _a.className,
      onRequestToClose = _a.onRequestToClose,
      onClose = _a.onClose,
      onOpen = _a.onOpen,
      open = _a.open,
      title = _a.title,
      _d = _a.labelledBy,
      labelledBy = _d === void 0 ? DEFAULT_LABEL_ID : _d,
      describedBy = _a.describedBy,
      primaryButton = _a.primaryButton,
      secondaryButtons = _a.secondaryButtons,
      _e = _a.variant,
      variant = _e === void 0 ? 'default' : _e,
      _f = _a.size,
      size = _f === void 0 ? 'small' : _f;

  var _g = useState(),
      closeButtonElement = _g[0],
      setCloseButtonElement = _g[1];

  var _h = useState(false),
      topShadow = _h[0],
      setTopShadow = _h[1];

  var _j = useState(false),
      bottomShadow = _j[0],
      setBottomShadow = _j[1];

  var setElement = useScrollObserver(function (percent) {
    setTopShadow(percent > 0);
    setBottomShadow(percent < 100);
  }).setElement;

  var getDialogButtons = function () {
    var primaryButtonArray = primaryButton ? [__assign(__assign({}, primaryButton), {
      isPrimary: true
    })] : [];
    var secondaryButtonsArray = (secondaryButtons === null || secondaryButtons === void 0 ? void 0 : secondaryButtons.map(function (button) {
      return __assign(__assign({}, button), {
        isPrimary: false
      });
    })) || [];
    return primaryButtonArray.concat(secondaryButtonsArray.reverse());
  };

  return /*#__PURE__*/React.createElement(Modal, {
    metadata: metadata,
    className: className,
    onClose: onClose,
    onOpen: onOpen,
    open: open,
    onRequestToClose: onRequestToClose
  }, /*#__PURE__*/React.createElement("section", {
    role: "dialog",
    "aria-modal": "true",
    "aria-labelledby": labelledBy,
    "aria-describedby": describedBy,
    className: classnames(styles.dialog, styles["size-" + size])
  }, /*#__PURE__*/React.createElement("header", {
    className: classnames(styles.header, (_b = {}, _b[styles.headerShadowed] = topShadow, _b))
  }, /*#__PURE__*/React.createElement(Typography, {
    component: "span",
    variant: "heading-3",
    className: styles.headerTitle,
    id: labelledBy
  }, title), /*#__PURE__*/React.createElement(IconButton, __assign({
    ref: setCloseButtonElement,
    icon: "times",
    ariaLabel: "Close Dialog",
    className: styles.closeButton,
    onClick: onRequestToClose,
    tabIndex: -1
  }, parseMetadata(suffixMetadata(metadata, 'close-button'))))), /*#__PURE__*/React.createElement("div", {
    ref: setElement,
    className: styles.body
  }, children), /*#__PURE__*/React.createElement("footer", {
    className: classnames(styles.footer, (_c = {}, _c[styles.footerShadowed] = bottomShadow, _c))
  }, getDialogButtons().map(function (button, index) {
    return /*#__PURE__*/React.createElement(DialogButton // eslint-disable-next-line react/no-array-index-key
    , __assign({
      // eslint-disable-next-line react/no-array-index-key
      key: (button.buttonLabel || button.buttonIcon) + "-" + index,
      variant: variant,
      onDialogButtonFocus: function () {
        if (closeButtonElement) closeButtonElement.tabIndex = 0;
      }
    }, button));
  }))));
};

export { Dialog as default };
//# sourceMappingURL=Dialog.js.map
